==> vtk6-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkODBCDatabase.java <==
// java wrapper for vtkODBCDatabase object
//

package vtk;
import vtk.*;

public class vtkODBCDatabase extends vtkSQLDatabase
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native boolean Open_2(String id0);
  public boolean Open(String id0)
    { return Open_2(id0); }

  private native void Close_3();
  public void Close()
    { Close_3(); }

  private native boolean IsOpen_4();
  public boolean IsOpen()
    { return IsOpen_4(); }

  private native long GetQueryInstance_5();
  public vtkSQLQuery GetQueryInstance() {
    long temp = GetQueryInstance_5();

    if (temp == 0) return null;
    return (vtkSQLQuery)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native String GetLastErrorText_6();
  public String GetLastErrorText()
    { return GetLastErrorText_6(); }

  private native long GetTables_7();
  public vtkStringArray GetTables() {
    long temp = GetTables_7();

    if (temp == 0) return null;
    return (vtkStringArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetRecord_8(String id0);
  public vtkStringArray GetRecord(String id0) {
    long temp = GetRecord_8(id0);

    if (temp == 0) return null;
    return (vtkStringArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native boolean IsSupported_9(int id0);
  public boolean IsSupported(int id0)
    { return IsSupported_9(id0); }

  private native void SetDataSourceName_10(String id0);
  public void SetDataSourceName(String id0)
    { SetDataSourceName_10(id0); }

  private native String GetDataSourceName_11();
  public String GetDataSourceName()
    { return GetDataSourceName_11(); }

  private native void SetServerPort_12(int id0);
  public void SetServerPort(int id0)
    { SetServerPort_12(id0); }

  private native void SetHostName_13(String id0);
  public void SetHostName(String id0)
    { SetHostName_13(id0); }

  private native void SetUserName_14(String id0);
  public void SetUserName(String id0)
    { SetUserName_14(id0); }

  private native void SetDatabaseName_15(String id0);
  public void SetDatabaseName(String id0)
    { SetDatabaseName_15(id0); }

  private native String GetDatabaseName_16();
  public String GetDatabaseName()
    { return GetDatabaseName_16(); }

  private native void SetPassword_17(String id0);
  public void SetPassword(String id0)
    { SetPassword_17(id0); }

  private native boolean HasError_18();
  public boolean HasError()
    { return HasError_18(); }

  private native String GetDatabaseType_19();
  public String GetDatabaseType()
    { return GetDatabaseType_19(); }

  private native String GetURL_20();
  public String GetURL()
    { return GetURL_20(); }

  private native String GetColumnSpecification_21(vtkSQLDatabaseSchema id0,int id1,int id2);
  public String GetColumnSpecification(vtkSQLDatabaseSchema id0,int id1,int id2)
    { return GetColumnSpecification_21(id0,id1,id2); }

  private native boolean CreateDatabase_22(String id0,boolean id1);
  public boolean CreateDatabase(String id0,boolean id1)
    { return CreateDatabase_22(id0,id1); }

  private native boolean DropDatabase_23(String id0);
  public boolean DropDatabase(String id0)
    { return DropDatabase_23(id0); }

  private native boolean ParseURL_24(String id0);
  public boolean ParseURL(String id0)
    { return ParseURL_24(id0); }

  public vtkODBCDatabase() { super(); }

  public vtkODBCDatabase(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-6-armv6h.pkg.tar.xz: vtk/vtkODBCDatabase.java <==
// java wrapper for vtkODBCDatabase object
//

package vtk;
import vtk.*;

public class vtkODBCDatabase extends vtkSQLDatabase
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native boolean Open_2(String id0);
  public boolean Open(String id0)
    { return Open_2(id0); }

  private native void Close_3();
  public void Close()
    { Close_3(); }

  private native boolean IsOpen_4();
  public boolean IsOpen()
    { return IsOpen_4(); }

  private native long GetQueryInstance_5();
  public vtkSQLQuery GetQueryInstance() {
    long temp = GetQueryInstance_5();

    if (temp == 0) return null;
    return (vtkSQLQuery)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native String GetLastErrorText_6();
  public String GetLastErrorText()
    { return GetLastErrorText_6(); }

  private native long GetTables_7();
  public vtkStringArray GetTables() {
    long temp = GetTables_7();

    if (temp == 0) return null;
    return (vtkStringArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetRecord_8(String id0);
  public vtkStringArray GetRecord(String id0) {
    long temp = GetRecord_8(id0);

    if (temp == 0) return null;
    return (vtkStringArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native boolean IsSupported_9(int id0);
  public boolean IsSupported(int id0)
    { return IsSupported_9(id0); }

  private native void SetDataSourceName_10(String id0);
  public void SetDataSourceName(String id0)
    { SetDataSourceName_10(id0); }

  private native String GetDataSourceName_11();
  public String GetDataSourceName()
    { return GetDataSourceName_11(); }

  private native void SetServerPort_12(int id0);
  public void SetServerPort(int id0)
    { SetServerPort_12(id0); }

  private native void SetHostName_13(String id0);
  public void SetHostName(String id0)
    { SetHostName_13(id0); }

  private native void SetUserName_14(String id0);
  public void SetUserName(String id0)
    { SetUserName_14(id0); }

  private native void SetDatabaseName_15(String id0);
  public void SetDatabaseName(String id0)
    { SetDatabaseName_15(id0); }

  private native String GetDatabaseName_16();
  public String GetDatabaseName()
    { return GetDatabaseName_16(); }

  private native void SetPassword_17(String id0);
  public void SetPassword(String id0)
    { SetPassword_17(id0); }

  private native boolean HasError_18();
  public boolean HasError()
    { return HasError_18(); }

  private native String GetDatabaseType_19();
  public String GetDatabaseType()
    { return GetDatabaseType_19(); }

  private native String GetURL_20();
  public String GetURL()
    { return GetURL_20(); }

  private native String GetColumnSpecification_21(vtkSQLDatabaseSchema id0,int id1,int id2);
  public String GetColumnSpecification(vtkSQLDatabaseSchema id0,int id1,int id2)
    { return GetColumnSpecification_21(id0,id1,id2); }

  private native boolean CreateDatabase_22(String id0,boolean id1);
  public boolean CreateDatabase(String id0,boolean id1)
    { return CreateDatabase_22(id0,id1); }

  private native boolean DropDatabase_23(String id0);
  public boolean DropDatabase(String id0)
    { return DropDatabase_23(id0); }

  private native boolean ParseURL_24(String id0);
  public boolean ParseURL(String id0)
    { return ParseURL_24(id0); }

  public vtkODBCDatabase() { super(); }

  public vtkODBCDatabase(long id) { super(id); }
  public native long   VTKInit();

}
